/*   -*- buffer-read-only: t -*- vi: set ro:
 *
 *  DO NOT EDIT THIS FILE   (tcpbridge_opts.c)
 *
 *  It has been AutoGen-ed
 *  From the definitions    ../../src/tcpbridge_opts.def
 *  and the template file   options
 *
 * Generated from AutoOpts 42:1:17 templates.
 *
 *  AutoOpts is a copyrighted work.  This source file is not encumbered
 *  by AutoOpts licensing, but is provided under the licensing terms chosen
 *  by the tcpbridge author or copyright holder.  AutoOpts is
 *  licensed under the terms of the LGPL.  The redistributable library
 *  (``libopts'') is licensed under the terms of either the LGPL or, at the
 *  users discretion, the BSD license.  See the AutoOpts and/or libopts sources
 *  for details.
 *
 * The tcpbridge program is copyrighted and licensed
 * under the following terms:
 *
 *  Copyright (C) 2000-2022 Aaron Turner and Fred Klassen, all rights reserved.
 *  This is free software. It is licensed for use, modification and
 *  redistribution under the terms of the GNU General Public License,
 *  version 3 or later <http://gnu.org/licenses/gpl.html>
 *
 *  tcpbridge is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  tcpbridge is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *  See the GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __doxygen__
#define OPTION_CODE_COMPILE 1
#include "tcpbridge_opts.h"
#include <sys/types.h>
#include <sys/stat.h>

#include <errno.h>
#include <fcntl.h>
#include <limits.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#ifdef  __cplusplus
extern "C" {
#endif
extern FILE * option_usage_fp;
#define zCopyright      (tcpbridge_opt_strs+0)
#define zLicenseDescrip (tcpbridge_opt_strs+283)

/*
 *  global included definitions
 */
#include "defines.h"
#include "tcpbridge.h"
#include "common.h"
#include "config.h"
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <unistd.h>
extern tcpbridge_opt_t options;


#ifndef NULL
#  define NULL 0
#endif

/**
 *  static const strings for tcpbridge options
 */
static char const tcpbridge_opt_strs[4593] =
/*     0 */ "tcpbridge (tcpbridge)\n"
            "Copyright (C) 2000-2022 Aaron Turner and Fred Klassen, all rights reserved.\n"
            "This is free software. It is licensed for use, modification and\n"
            "redistribution under the terms of the GNU General Public License,\n"
            "version 3 or later <http://gnu.org/licenses/gpl.html>\n\0"
/*   283 */ "tcpbridge is free software: you can redistribute it and/or modify it under\n"
            "the terms of the GNU General Public License as published by the Free\n"
            "Software Foundation, either version 3 of the License, or (at your option)\n"
            "any later version.\n\n"
            "tcpbridge is distributed in the hope that it will be useful, but WITHOUT\n"
            "ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or\n"
            "FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for\n"
            "more details.\n\n"
            "You should have received a copy of the GNU General Public License along\n"
            "with this program.  If not, see <http://www.gnu.org/licenses/>.\n\0"
/*   890 */ ":\0"
/*   892 */ "Rewrite TCP/UDP ports\0"
/*   914 */ "PORTMAP\0"
/*   922 */ "portmap\0"
/*   930 */ "Randomize src/dst IPv4/v6 addresses w/ given seed\0"
/*   980 */ "SEED\0"
/*   985 */ "seed\0"
/*   990 */ "Rewrite IPv4/v6 addresses using pseudo-NAT\0"
/*  1033 */ "PNAT\0"
/*  1038 */ "pnat\0"
/*  1043 */ "Rewrite source IPv4/v6 addresses using pseudo-NAT\0"
/*  1093 */ "SRCIPMAP\0"
/*  1102 */ "srcipmap\0"
/*  1111 */ "Rewrite destination IPv4/v6 addresses using pseudo-NAT\0"
/*  1166 */ "DSTIPMAP\0"
/*  1175 */ "dstipmap\0"
/*  1184 */ "Rewrite IP addresses to be between two endpoints\0"
/*  1233 */ "ENDPOINTS\0"
/*  1243 */ "endpoints\0"
/*  1253 */ "Change TCP Sequence (and ACK) numbers /w given seed\0"
/*  1305 */ "TCP_SEQUENCE\0"
/*  1318 */ "tcp-sequence\0"
/*  1331 */ "Skip rewriting broadcast/multicast IPv4/v6 addresses\0"
/*  1384 */ "SKIPBROADCAST\0"
/*  1398 */ "skipbroadcast\0"
/*  1412 */ "Force recalculation of IPv4/TCP/UDP header checksums\0"
/*  1465 */ "FIXCSUM\0"
/*  1473 */ "fixcsum\0"
/*  1481 */ "Override default MTU length (1500 bytes)\0"
/*  1522 */ "MTU\0"
/*  1526 */ "mtu\0"
/*  1530 */ "Truncate packets larger then specified MTU\0"
/*  1573 */ "MTU_TRUNC\0"
/*  1583 */ "mtu-trunc\0"
/*  1593 */ "Remove Ethernet checksums (FCS) from end of frames\0"
/*  1644 */ "EFCS\0"
/*  1649 */ "efcs\0"
/*  1654 */ "Modify the IPv4/v6 TTL/Hop Limit\0"
/*  1687 */ "TTL\0"
/*  1691 */ "ttl\0"
/*  1695 */ "Set the IPv4 TOS/DiffServ/ECN byte\0"
/*  1730 */ "TOS\0"
/*  1734 */ "tos\0"
/*  1738 */ "Set the IPv6 Traffic Class byte\0"
/*  1770 */ "TCLASS\0"
/*  1777 */ "tclass\0"
/*  1784 */ "Set the IPv6 Flow Label\0"
/*  1808 */ "FLOWLABEL\0"
/*  1818 */ "flowlabel\0"
/*  1828 */ "Pad or truncate packet data to match header length\0"
/*  1879 */ "FIXLEN\0"
/*  1886 */ "fixlen\0"
/*  1893 */ "Fuzz 1 in X packets.  Edit bytes, length, or emulate packet drop\0"
/*  1958 */ "FUZZ_SEED\0"
/*  1968 */ "fuzz-seed\0"
/*  1978 */ "Set the Fuzz 1 in X packet ratio (default 1 in 8 packets)\0"
/*  2036 */ "FUZZ_FACTOR\0"
/*  2048 */ "fuzz-factor\0"
/*  2060 */ "Skip rewriting broadcast/multicast Layer 2 addresses\0"
/*  2113 */ "SKIPL2BROADCAST\0"
/*  2129 */ "skipl2broadcast\0"
/*  2145 */ "Override output DLT encapsulation\0"
/*  2179 */ "DLT\0"
/*  2183 */ "dlt\0"
/*  2187 */ "Override destination ethernet MAC addresses\0"
/*  2231 */ "ENET_DMAC\0"
/*  2241 */ "enet-dmac\0"
/*  2251 */ "Override source ethernet MAC addresses\0"
/*  2290 */ "ENET_SMAC\0"
/*  2300 */ "enet-smac\0"
/*  2310 */ "Substitute MAC addresses\0"
/*  2335 */ "ENET_SUBSMAC\0"
/*  2348 */ "enet-subsmac\0"
/*  2361 */ "Randomize MAC addresses\0"
/*  2385 */ "ENET_MAC_SEED\0"
/*  2399 */ "enet-mac-seed\0"
/*  2413 */ "ENET_MAC_SEED_KEEP_BYTES\0"
/*  2438 */ "enet-mac-seed-keep-bytes\0"
/*  2463 */ "Specify ethernet 802.1q VLAN tag mode\0"
/*  2501 */ "ENET_VLAN\0"
/*  2511 */ "enet-vlan\0"
/*  2521 */ "Specify the new ethernet 802.1q VLAN tag value\0"
/*  2568 */ "ENET_VLAN_TAG\0"
/*  2582 */ "enet-vlan-tag\0"
/*  2596 */ "Specify the ethernet 802.1q VLAN CFI value\0"
/*  2639 */ "ENET_VLAN_CFI\0"
/*  2653 */ "enet-vlan-cfi\0"
/*  2667 */ "Specify the ethernet 802.1q VLAN priority\0"
/*  2709 */ "ENET_VLAN_PRI\0"
/*  2723 */ "enet-vlan-pri\0"
/*  2737 */ "Specify VLAN tag protocol 802.1q or 802.1ad\0"
/*  2781 */ "ENET_VLAN_PROTO\0"
/*  2797 */ "enet-vlan-proto\0"
/*  2813 */ "Specify HDLC control value\0"
/*  2840 */ "HDLC_CONTROL\0"
/*  2853 */ "hdlc-control\0"
/*  2866 */ "Specify HDLC address\0"
/*  2887 */ "HDLC_ADDRESS\0"
/*  2900 */ "hdlc-address\0"
/*  2913 */ "Set output file DLT type\0"
/*  2938 */ "USER_DLT\0"
/*  2947 */ "user-dlt\0"
/*  2956 */ "Rewrite Data-Link layer with user specified data\0"
/*  3005 */ "USER_DLINK\0"
/*  3016 */ "user-dlink\0"
/*  3027 */ "Enable debugging output\0"
/*  3051 */ "DBUG\0"
/*  3056 */ "dbug\0"
/*  3061 */ "Primary interface (listen in uni-directional mode)\0"
/*  3112 */ "INTF1\0"
/*  3118 */ "intf1\0"
/*  3124 */ "Secondary interface (send in uni-directional mode)\0"
/*  3175 */ "INTF2\0"
/*  3181 */ "intf2\0"
/*  3187 */ "Send and receive in only one direction\0"
/*  3226 */ "UNIDIR\0"
/*  3233 */ "unidir\0"
/*  3240 */ "List available network interfaces and exit\0"
/*  3283 */ "LISTNICS\0"
/*  3292 */ "listnics\0"
/*  3301 */ "Limit the number of packets to send\0"
/*  3337 */ "LIMIT\0"
/*  3343 */ "limit\0"
/*  3349 */ "MAC addresses of local NIC's\0"
/*  3378 */ "MAC\0"
/*  3382 */ "mac\0"
/*  3386 */ "Include only packets matching rule\0"
/*  3421 */ "INCLUDE\0"
/*  3429 */ "include\0"
/*  3437 */ "Exclude any packet matching this rule\0"
/*  3475 */ "EXCLUDE\0"
/*  3483 */ "exclude\0"
/*  3491 */ "Print the PID of tcpbridge at startup\0"
/*  3529 */ "PID\0"
/*  3533 */ "pid\0"
/*  3537 */ "Print decoded packets via tcpdump to STDOUT\0"
/*  3581 */ "VERBOSE\0"
/*  3589 */ "verbose\0"
/*  3597 */ "Arguments passed to tcpdump decoder\0"
/*  3633 */ "DECODE\0"
/*  3640 */ "decode\0"
/*  3647 */ "Print version information\0"
/*  3673 */ "VERSION\0"
/*  3681 */ "version\0"
/*  3689 */ "Display less usage information and exit\0"
/*  3729 */ "LESS_HELP\0"
/*  3739 */ "less-help\0"
/*  3749 */ "display extended usage information and exit\0"
/*  3793 */ "help\0"
/*  3798 */ "extended usage information passed thru pager\0"
/*  3843 */ "more-help\0"
/*  3853 */ "save the option state to a config file\0"
/*  3892 */ "save-opts\0"
/*  3902 */ "load options from a config file\0"
/*  3934 */ "LOAD_OPTS\0"
/*  3944 */ "no-load-opts\0"
/*  3957 */ "no\0"
/*  3960 */ "TCPBRIDGE\0"
/*  3970 */ "tcpbridge (tcpbridge) - Bridge network traffic across two interfaces\n"
            "Usage:  %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]...\n\0"
/*  4097 */ "$$/\0"
/*  4101 */ ".tcpbridgerc\0"
/*  4114 */ "tcpreplay-users@lists.sourceforge.net\0"
/*  4152 */ "tcpbridge is a tool for selectively bridging network traffic across two\n"
            "interfaces and optionally modifying the packets in between\n\0"
/*  4284 */ "The basic operation of tcpbridge is to be a network bridge between two\n"
            "subnets.  All packets received on one interface are sent via the other.\n\n"
            "Optionally, packets can be edited in a variety of ways according to your\n"
            "needs.\n\n"
            "For more details, please see the Tcpreplay Manual at:\n"
            "http://tcpreplay.appneta.com\n";

/**
 *  tcpedit option description:
 */
/** tcpedit option separation text */
#define TCPEDIT_DESC      (tcpbridge_opt_strs+890)
#define TCPEDIT_FLAGS     (OPTST_DOCUMENT | OPTST_NO_INIT)

/**
 *  portmap option description:
 */
/** Descriptive text for the portmap option */
#define PORTMAP_DESC      (tcpbridge_opt_strs+892)
/** Upper-cased name for the portmap option */
#define PORTMAP_NAME      (tcpbridge_opt_strs+914)
/** Name string for the portmap option */
#define PORTMAP_name      (tcpbridge_opt_strs+922)
/** Compiled in flag settings for the portmap option */
#define PORTMAP_FLAGS     (OPTST_DISABLED | OPTST_STACKED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  seed option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the seed option */
#define SEED_DESC      (tcpbridge_opt_strs+930)
/** Upper-cased name for the seed option */
#define SEED_NAME      (tcpbridge_opt_strs+980)
/** Name string for the seed option */
#define SEED_name      (tcpbridge_opt_strs+985)
/** Other options that appear in conjunction with the seed option */
static int const aSeedCantList[] = {
    INDEX_OPT_FUZZ_SEED, NO_EQUIVALENT };
/** Compiled in flag settings for the seed option */
#define SEED_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  pnat option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the pnat option */
#define PNAT_DESC      (tcpbridge_opt_strs+990)
/** Upper-cased name for the pnat option */
#define PNAT_NAME      (tcpbridge_opt_strs+1033)
/** Name string for the pnat option */
#define PNAT_name      (tcpbridge_opt_strs+1038)
/** Other options that appear in conjunction with the pnat option */
static int const aPnatCantList[] = {
    INDEX_OPT_SRCIPMAP, NO_EQUIVALENT };
/** Compiled in flag settings for the pnat option */
#define PNAT_FLAGS     (OPTST_DISABLED | OPTST_STACKED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  srcipmap option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the srcipmap option */
#define SRCIPMAP_DESC      (tcpbridge_opt_strs+1043)
/** Upper-cased name for the srcipmap option */
#define SRCIPMAP_NAME      (tcpbridge_opt_strs+1093)
/** Name string for the srcipmap option */
#define SRCIPMAP_name      (tcpbridge_opt_strs+1102)
/** Other options that appear in conjunction with the srcipmap option */
static int const aSrcipmapCantList[] = {
    INDEX_OPT_PNAT, NO_EQUIVALENT };
/** Compiled in flag settings for the srcipmap option */
#define SRCIPMAP_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  dstipmap option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the dstipmap option */
#define DSTIPMAP_DESC      (tcpbridge_opt_strs+1111)
/** Upper-cased name for the dstipmap option */
#define DSTIPMAP_NAME      (tcpbridge_opt_strs+1166)
/** Name string for the dstipmap option */
#define DSTIPMAP_name      (tcpbridge_opt_strs+1175)
/** Other options that appear in conjunction with the dstipmap option */
static int const aDstipmapCantList[] = {
    INDEX_OPT_PNAT, NO_EQUIVALENT };
/** Compiled in flag settings for the dstipmap option */
#define DSTIPMAP_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  endpoints option description with
 *  "Must also have options" and "Incompatible options":
 */
#ifdef HAVE_CACHEFILE_SUPPORT
/** Descriptive text for the endpoints option */
#define ENDPOINTS_DESC      (tcpbridge_opt_strs+1184)
/** Upper-cased name for the endpoints option */
#define ENDPOINTS_NAME      (tcpbridge_opt_strs+1233)
/** Name string for the endpoints option */
#define ENDPOINTS_name      (tcpbridge_opt_strs+1243)
/** Other options that are required by the endpoints option */
static int const aEndpointsMustList[] = {
    INDEX_OPT_CACHEFILE, NO_EQUIVALENT };
/** Compiled in flag settings for the endpoints option */
#define ENDPOINTS_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

#else   /* disable endpoints */
#define ENDPOINTS_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define aEndpointsMustList   NULL
#define ENDPOINTS_NAME      NULL
#define ENDPOINTS_DESC      NULL
#define ENDPOINTS_name      NULL
#endif  /* HAVE_CACHEFILE_SUPPORT */

/**
 *  tcp-sequence option description:
 */
/** Descriptive text for the tcp-sequence option */
#define TCP_SEQUENCE_DESC      (tcpbridge_opt_strs+1253)
/** Upper-cased name for the tcp-sequence option */
#define TCP_SEQUENCE_NAME      (tcpbridge_opt_strs+1305)
/** Name string for the tcp-sequence option */
#define TCP_SEQUENCE_name      (tcpbridge_opt_strs+1318)
/** The compiled in default value for the tcp-sequence option argument */
#define TCP_SEQUENCE_DFT_ARG   ((char const*)0)
/** Compiled in flag settings for the tcp-sequence option */
#define TCP_SEQUENCE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  skipbroadcast option description:
 */
/** Descriptive text for the skipbroadcast option */
#define SKIPBROADCAST_DESC      (tcpbridge_opt_strs+1331)
/** Upper-cased name for the skipbroadcast option */
#define SKIPBROADCAST_NAME      (tcpbridge_opt_strs+1384)
/** Name string for the skipbroadcast option */
#define SKIPBROADCAST_name      (tcpbridge_opt_strs+1398)
/** Compiled in flag settings for the skipbroadcast option */
#define SKIPBROADCAST_FLAGS     (OPTST_DISABLED)

/**
 *  fixcsum option description:
 */
/** Descriptive text for the fixcsum option */
#define FIXCSUM_DESC      (tcpbridge_opt_strs+1412)
/** Upper-cased name for the fixcsum option */
#define FIXCSUM_NAME      (tcpbridge_opt_strs+1465)
/** Name string for the fixcsum option */
#define FIXCSUM_name      (tcpbridge_opt_strs+1473)
/** Compiled in flag settings for the fixcsum option */
#define FIXCSUM_FLAGS     (OPTST_DISABLED)

/**
 *  mtu option description:
 */
/** Descriptive text for the mtu option */
#define MTU_DESC      (tcpbridge_opt_strs+1481)
/** Upper-cased name for the mtu option */
#define MTU_NAME      (tcpbridge_opt_strs+1522)
/** Name string for the mtu option */
#define MTU_name      (tcpbridge_opt_strs+1526)
/** Compiled in flag settings for the mtu option */
#define MTU_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  mtu-trunc option description:
 */
/** Descriptive text for the mtu-trunc option */
#define MTU_TRUNC_DESC      (tcpbridge_opt_strs+1530)
/** Upper-cased name for the mtu-trunc option */
#define MTU_TRUNC_NAME      (tcpbridge_opt_strs+1573)
/** Name string for the mtu-trunc option */
#define MTU_TRUNC_name      (tcpbridge_opt_strs+1583)
/** Compiled in flag settings for the mtu-trunc option */
#define MTU_TRUNC_FLAGS     (OPTST_DISABLED)

/**
 *  efcs option description:
 */
/** Descriptive text for the efcs option */
#define EFCS_DESC      (tcpbridge_opt_strs+1593)
/** Upper-cased name for the efcs option */
#define EFCS_NAME      (tcpbridge_opt_strs+1644)
/** Name string for the efcs option */
#define EFCS_name      (tcpbridge_opt_strs+1649)
/** Compiled in flag settings for the efcs option */
#define EFCS_FLAGS     (OPTST_DISABLED)

/**
 *  ttl option description:
 */
/** Descriptive text for the ttl option */
#define TTL_DESC      (tcpbridge_opt_strs+1654)
/** Upper-cased name for the ttl option */
#define TTL_NAME      (tcpbridge_opt_strs+1687)
/** Name string for the ttl option */
#define TTL_name      (tcpbridge_opt_strs+1691)
/** Compiled in flag settings for the ttl option */
#define TTL_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  tos option description:
 */
/** Descriptive text for the tos option */
#define TOS_DESC      (tcpbridge_opt_strs+1695)
/** Upper-cased name for the tos option */
#define TOS_NAME      (tcpbridge_opt_strs+1730)
/** Name string for the tos option */
#define TOS_name      (tcpbridge_opt_strs+1734)
/** Compiled in flag settings for the tos option */
#define TOS_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  tclass option description:
 */
/** Descriptive text for the tclass option */
#define TCLASS_DESC      (tcpbridge_opt_strs+1738)
/** Upper-cased name for the tclass option */
#define TCLASS_NAME      (tcpbridge_opt_strs+1770)
/** Name string for the tclass option */
#define TCLASS_name      (tcpbridge_opt_strs+1777)
/** Compiled in flag settings for the tclass option */
#define TCLASS_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  flowlabel option description:
 */
/** Descriptive text for the flowlabel option */
#define FLOWLABEL_DESC      (tcpbridge_opt_strs+1784)
/** Upper-cased name for the flowlabel option */
#define FLOWLABEL_NAME      (tcpbridge_opt_strs+1808)
/** Name string for the flowlabel option */
#define FLOWLABEL_name      (tcpbridge_opt_strs+1818)
/** Compiled in flag settings for the flowlabel option */
#define FLOWLABEL_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  fixlen option description:
 */
/** Descriptive text for the fixlen option */
#define FIXLEN_DESC      (tcpbridge_opt_strs+1828)
/** Upper-cased name for the fixlen option */
#define FIXLEN_NAME      (tcpbridge_opt_strs+1879)
/** Name string for the fixlen option */
#define FIXLEN_name      (tcpbridge_opt_strs+1886)
/** Compiled in flag settings for the fixlen option */
#define FIXLEN_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  fuzz-seed option description:
 */
/** Descriptive text for the fuzz-seed option */
#define FUZZ_SEED_DESC      (tcpbridge_opt_strs+1893)
/** Upper-cased name for the fuzz-seed option */
#define FUZZ_SEED_NAME      (tcpbridge_opt_strs+1958)
/** Name string for the fuzz-seed option */
#define FUZZ_SEED_name      (tcpbridge_opt_strs+1968)
/** The compiled in default value for the fuzz-seed option argument */
#define FUZZ_SEED_DFT_ARG   ((char const*)0)
/** Compiled in flag settings for the fuzz-seed option */
#define FUZZ_SEED_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  fuzz-factor option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the fuzz-factor option */
#define FUZZ_FACTOR_DESC      (tcpbridge_opt_strs+1978)
/** Upper-cased name for the fuzz-factor option */
#define FUZZ_FACTOR_NAME      (tcpbridge_opt_strs+2036)
/** Name string for the fuzz-factor option */
#define FUZZ_FACTOR_name      (tcpbridge_opt_strs+2048)
/** The compiled in default value for the fuzz-factor option argument */
#define FUZZ_FACTOR_DFT_ARG   ((char const*)8)
/** Other options that are required by the fuzz-factor option */
static int const aFuzz_FactorMustList[] = {
    INDEX_OPT_FUZZ_SEED, NO_EQUIVALENT };
/** Compiled in flag settings for the fuzz-factor option */
#define FUZZ_FACTOR_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  skipl2broadcast option description:
 */
/** Descriptive text for the skipl2broadcast option */
#define SKIPL2BROADCAST_DESC      (tcpbridge_opt_strs+2060)
/** Upper-cased name for the skipl2broadcast option */
#define SKIPL2BROADCAST_NAME      (tcpbridge_opt_strs+2113)
/** Name string for the skipl2broadcast option */
#define SKIPL2BROADCAST_name      (tcpbridge_opt_strs+2129)
/** Compiled in flag settings for the skipl2broadcast option */
#define SKIPL2BROADCAST_FLAGS     (OPTST_DISABLED)

/**
 *  dlt option description:
 */
/** Descriptive text for the dlt option */
#define DLT_DESC      (tcpbridge_opt_strs+2145)
/** Upper-cased name for the dlt option */
#define DLT_NAME      (tcpbridge_opt_strs+2179)
/** Name string for the dlt option */
#define DLT_name      (tcpbridge_opt_strs+2183)
/** Compiled in flag settings for the dlt option */
#define DLT_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  enet-dmac option description:
 */
/** Descriptive text for the enet-dmac option */
#define ENET_DMAC_DESC      (tcpbridge_opt_strs+2187)
/** Upper-cased name for the enet-dmac option */
#define ENET_DMAC_NAME      (tcpbridge_opt_strs+2231)
/** Name string for the enet-dmac option */
#define ENET_DMAC_name      (tcpbridge_opt_strs+2241)
/** Compiled in flag settings for the enet-dmac option */
#define ENET_DMAC_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  enet-smac option description:
 */
/** Descriptive text for the enet-smac option */
#define ENET_SMAC_DESC      (tcpbridge_opt_strs+2251)
/** Upper-cased name for the enet-smac option */
#define ENET_SMAC_NAME      (tcpbridge_opt_strs+2290)
/** Name string for the enet-smac option */
#define ENET_SMAC_name      (tcpbridge_opt_strs+2300)
/** Compiled in flag settings for the enet-smac option */
#define ENET_SMAC_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  enet-subsmac option description:
 */
/** Descriptive text for the enet-subsmac option */
#define ENET_SUBSMAC_DESC      (tcpbridge_opt_strs+2310)
/** Upper-cased name for the enet-subsmac option */
#define ENET_SUBSMAC_NAME      (tcpbridge_opt_strs+2335)
/** Name string for the enet-subsmac option */
#define ENET_SUBSMAC_name      (tcpbridge_opt_strs+2348)
/** Compiled in flag settings for the enet-subsmac option */
#define ENET_SUBSMAC_FLAGS     (OPTST_DISABLED | OPTST_STACKED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  enet-mac-seed option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the enet-mac-seed option */
#define ENET_MAC_SEED_DESC      (tcpbridge_opt_strs+2361)
/** Upper-cased name for the enet-mac-seed option */
#define ENET_MAC_SEED_NAME      (tcpbridge_opt_strs+2385)
/** Name string for the enet-mac-seed option */
#define ENET_MAC_SEED_name      (tcpbridge_opt_strs+2399)
/** Other options that appear in conjunction with the enet-mac-seed option */
static int const aEnet_Mac_SeedCantList[] = {
    INDEX_OPT_ENET_SMAC,
    INDEX_OPT_ENET_DMAC,
    INDEX_OPT_ENET_SUBSMAC, NO_EQUIVALENT };
/** Compiled in flag settings for the enet-mac-seed option */
#define ENET_MAC_SEED_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  enet-mac-seed-keep-bytes option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the enet-mac-seed-keep-bytes option */
#define ENET_MAC_SEED_KEEP_BYTES_DESC      (tcpbridge_opt_strs+2361)
/** Upper-cased name for the enet-mac-seed-keep-bytes option */
#define ENET_MAC_SEED_KEEP_BYTES_NAME      (tcpbridge_opt_strs+2413)
/** Name string for the enet-mac-seed-keep-bytes option */
#define ENET_MAC_SEED_KEEP_BYTES_name      (tcpbridge_opt_strs+2438)
/** Other options that are required by the enet-mac-seed-keep-bytes option */
static int const aEnet_Mac_Seed_Keep_BytesMustList[] = {
    INDEX_OPT_ENET_MAC_SEED, NO_EQUIVALENT };
/** Compiled in flag settings for the enet-mac-seed-keep-bytes option */
#define ENET_MAC_SEED_KEEP_BYTES_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  enet-vlan option description:
 */
/** Descriptive text for the enet-vlan option */
#define ENET_VLAN_DESC      (tcpbridge_opt_strs+2463)
/** Upper-cased name for the enet-vlan option */
#define ENET_VLAN_NAME      (tcpbridge_opt_strs+2501)
/** Name string for the enet-vlan option */
#define ENET_VLAN_name      (tcpbridge_opt_strs+2511)
/** Compiled in flag settings for the enet-vlan option */
#define ENET_VLAN_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  enet-vlan-tag option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the enet-vlan-tag option */
#define ENET_VLAN_TAG_DESC      (tcpbridge_opt_strs+2521)
/** Upper-cased name for the enet-vlan-tag option */
#define ENET_VLAN_TAG_NAME      (tcpbridge_opt_strs+2568)
/** Name string for the enet-vlan-tag option */
#define ENET_VLAN_TAG_name      (tcpbridge_opt_strs+2582)
/** Other options that are required by the enet-vlan-tag option */
static int const aEnet_Vlan_TagMustList[] = {
    INDEX_OPT_ENET_VLAN, NO_EQUIVALENT };
/** Compiled in flag settings for the enet-vlan-tag option */
#define ENET_VLAN_TAG_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  enet-vlan-cfi option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the enet-vlan-cfi option */
#define ENET_VLAN_CFI_DESC      (tcpbridge_opt_strs+2596)
/** Upper-cased name for the enet-vlan-cfi option */
#define ENET_VLAN_CFI_NAME      (tcpbridge_opt_strs+2639)
/** Name string for the enet-vlan-cfi option */
#define ENET_VLAN_CFI_name      (tcpbridge_opt_strs+2653)
/** Other options that are required by the enet-vlan-cfi option */
static int const aEnet_Vlan_CfiMustList[] = {
    INDEX_OPT_ENET_VLAN, NO_EQUIVALENT };
/** Compiled in flag settings for the enet-vlan-cfi option */
#define ENET_VLAN_CFI_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  enet-vlan-pri option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the enet-vlan-pri option */
#define ENET_VLAN_PRI_DESC      (tcpbridge_opt_strs+2667)
/** Upper-cased name for the enet-vlan-pri option */
#define ENET_VLAN_PRI_NAME      (tcpbridge_opt_strs+2709)
/** Name string for the enet-vlan-pri option */
#define ENET_VLAN_PRI_name      (tcpbridge_opt_strs+2723)
/** Other options that are required by the enet-vlan-pri option */
static int const aEnet_Vlan_PriMustList[] = {
    INDEX_OPT_ENET_VLAN, NO_EQUIVALENT };
/** Compiled in flag settings for the enet-vlan-pri option */
#define ENET_VLAN_PRI_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  enet-vlan-proto option description:
 */
/** Descriptive text for the enet-vlan-proto option */
#define ENET_VLAN_PROTO_DESC      (tcpbridge_opt_strs+2737)
/** Upper-cased name for the enet-vlan-proto option */
#define ENET_VLAN_PROTO_NAME      (tcpbridge_opt_strs+2781)
/** Name string for the enet-vlan-proto option */
#define ENET_VLAN_PROTO_name      (tcpbridge_opt_strs+2797)
/** Compiled in flag settings for the enet-vlan-proto option */
#define ENET_VLAN_PROTO_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  hdlc-control option description:
 */
/** Descriptive text for the hdlc-control option */
#define HDLC_CONTROL_DESC      (tcpbridge_opt_strs+2813)
/** Upper-cased name for the hdlc-control option */
#define HDLC_CONTROL_NAME      (tcpbridge_opt_strs+2840)
/** Name string for the hdlc-control option */
#define HDLC_CONTROL_name      (tcpbridge_opt_strs+2853)
/** Compiled in flag settings for the hdlc-control option */
#define HDLC_CONTROL_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  hdlc-address option description:
 */
/** Descriptive text for the hdlc-address option */
#define HDLC_ADDRESS_DESC      (tcpbridge_opt_strs+2866)
/** Upper-cased name for the hdlc-address option */
#define HDLC_ADDRESS_NAME      (tcpbridge_opt_strs+2887)
/** Name string for the hdlc-address option */
#define HDLC_ADDRESS_name      (tcpbridge_opt_strs+2900)
/** Compiled in flag settings for the hdlc-address option */
#define HDLC_ADDRESS_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  user-dlt option description:
 */
/** Descriptive text for the user-dlt option */
#define USER_DLT_DESC      (tcpbridge_opt_strs+2913)
/** Upper-cased name for the user-dlt option */
#define USER_DLT_NAME      (tcpbridge_opt_strs+2938)
/** Name string for the user-dlt option */
#define USER_DLT_name      (tcpbridge_opt_strs+2947)
/** Compiled in flag settings for the user-dlt option */
#define USER_DLT_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  user-dlink option description:
 */
/** Descriptive text for the user-dlink option */
#define USER_DLINK_DESC      (tcpbridge_opt_strs+2956)
/** Upper-cased name for the user-dlink option */
#define USER_DLINK_NAME      (tcpbridge_opt_strs+3005)
/** Name string for the user-dlink option */
#define USER_DLINK_name      (tcpbridge_opt_strs+3016)
/** Compiled in flag settings for the user-dlink option */
#define USER_DLINK_FLAGS     (OPTST_DISABLED | OPTST_STACKED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  dbug option description:
 */
#ifdef DEBUG
/** Descriptive text for the dbug option */
#define DBUG_DESC      (tcpbridge_opt_strs+3027)
/** Upper-cased name for the dbug option */
#define DBUG_NAME      (tcpbridge_opt_strs+3051)
/** Name string for the dbug option */
#define DBUG_name      (tcpbridge_opt_strs+3056)
/** The compiled in default value for the dbug option argument */
#define DBUG_DFT_ARG   ((char const*)0)
/** Compiled in flag settings for the dbug option */
#define DBUG_FLAGS     (OPTST_DISABLED | OPTST_IMM \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

#else   /* disable dbug */
#define DBUG_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define DBUG_DFT_ARG   NULL
#define DBUG_NAME      NULL
#define DBUG_DESC      NULL
#define DBUG_name      NULL
#endif  /* DEBUG */

/**
 *  intf1 option description:
 */
/** Descriptive text for the intf1 option */
#define INTF1_DESC      (tcpbridge_opt_strs+3061)
/** Upper-cased name for the intf1 option */
#define INTF1_NAME      (tcpbridge_opt_strs+3112)
/** Name string for the intf1 option */
#define INTF1_name      (tcpbridge_opt_strs+3118)
/** Compiled in flag settings for the intf1 option */
#define INTF1_FLAGS     (OPTST_DISABLED | OPTST_MUST_SET \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  intf2 option description:
 */
/** Descriptive text for the intf2 option */
#define INTF2_DESC      (tcpbridge_opt_strs+3124)
/** Upper-cased name for the intf2 option */
#define INTF2_NAME      (tcpbridge_opt_strs+3175)
/** Name string for the intf2 option */
#define INTF2_name      (tcpbridge_opt_strs+3181)
/** Compiled in flag settings for the intf2 option */
#define INTF2_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  unidir option description:
 */
/** Descriptive text for the unidir option */
#define UNIDIR_DESC      (tcpbridge_opt_strs+3187)
/** Upper-cased name for the unidir option */
#define UNIDIR_NAME      (tcpbridge_opt_strs+3226)
/** Name string for the unidir option */
#define UNIDIR_name      (tcpbridge_opt_strs+3233)
/** Compiled in flag settings for the unidir option */
#define UNIDIR_FLAGS     (OPTST_DISABLED)

/**
 *  listnics option description:
 */
#ifdef ENABLE_PCAP_FINDALLDEVS
/** Descriptive text for the listnics option */
#define LISTNICS_DESC      (tcpbridge_opt_strs+3240)
/** Upper-cased name for the listnics option */
#define LISTNICS_NAME      (tcpbridge_opt_strs+3283)
/** Name string for the listnics option */
#define LISTNICS_name      (tcpbridge_opt_strs+3292)
/** Compiled in flag settings for the listnics option */
#define LISTNICS_FLAGS     (OPTST_DISABLED | OPTST_IMM)

#else   /* disable listnics */
#define LISTNICS_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define LISTNICS_NAME      NULL
#define LISTNICS_DESC      NULL
#define LISTNICS_name      NULL
#endif  /* ENABLE_PCAP_FINDALLDEVS */

/**
 *  limit option description:
 */
/** Descriptive text for the limit option */
#define LIMIT_DESC      (tcpbridge_opt_strs+3301)
/** Upper-cased name for the limit option */
#define LIMIT_NAME      (tcpbridge_opt_strs+3337)
/** Name string for the limit option */
#define LIMIT_name      (tcpbridge_opt_strs+3343)
/** The compiled in default value for the limit option argument */
#define LIMIT_DFT_ARG   ((char const*)-1)
/** Compiled in flag settings for the limit option */
#define LIMIT_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  mac option description:
 */
/** Descriptive text for the mac option */
#define MAC_DESC      (tcpbridge_opt_strs+3349)
/** Upper-cased name for the mac option */
#define MAC_NAME      (tcpbridge_opt_strs+3378)
/** Name string for the mac option */
#define MAC_name      (tcpbridge_opt_strs+3382)
/** Compiled in flag settings for the mac option */
#define MAC_FLAGS     (OPTST_DISABLED | OPTST_STACKED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  include option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the include option */
#define INCLUDE_DESC      (tcpbridge_opt_strs+3386)
/** Upper-cased name for the include option */
#define INCLUDE_NAME      (tcpbridge_opt_strs+3421)
/** Name string for the include option */
#define INCLUDE_name      (tcpbridge_opt_strs+3429)
/** Other options that appear in conjunction with the include option */
static int const aIncludeCantList[] = {
    INDEX_OPT_EXCLUDE, NO_EQUIVALENT };
/** Compiled in flag settings for the include option */
#define INCLUDE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  exclude option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the exclude option */
#define EXCLUDE_DESC      (tcpbridge_opt_strs+3437)
/** Upper-cased name for the exclude option */
#define EXCLUDE_NAME      (tcpbridge_opt_strs+3475)
/** Name string for the exclude option */
#define EXCLUDE_name      (tcpbridge_opt_strs+3483)
/** Other options that appear in conjunction with the exclude option */
static int const aExcludeCantList[] = {
    INDEX_OPT_INCLUDE, NO_EQUIVALENT };
/** Compiled in flag settings for the exclude option */
#define EXCLUDE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  pid option description:
 */
/** Descriptive text for the pid option */
#define PID_DESC      (tcpbridge_opt_strs+3491)
/** Upper-cased name for the pid option */
#define PID_NAME      (tcpbridge_opt_strs+3529)
/** Name string for the pid option */
#define PID_name      (tcpbridge_opt_strs+3533)
/** Compiled in flag settings for the pid option */
#define PID_FLAGS     (OPTST_DISABLED)

/**
 *  verbose option description:
 */
#ifdef ENABLE_VERBOSE
/** Descriptive text for the verbose option */
#define VERBOSE_DESC      (tcpbridge_opt_strs+3537)
/** Upper-cased name for the verbose option */
#define VERBOSE_NAME      (tcpbridge_opt_strs+3581)
/** Name string for the verbose option */
#define VERBOSE_name      (tcpbridge_opt_strs+3589)
/** Compiled in flag settings for the verbose option */
#define VERBOSE_FLAGS     (OPTST_DISABLED | OPTST_IMM)

#else   /* disable verbose */
#define VERBOSE_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define VERBOSE_NAME      NULL
#define VERBOSE_DESC      NULL
#define VERBOSE_name      NULL
#endif  /* ENABLE_VERBOSE */

/**
 *  decode option description with
 *  "Must also have options" and "Incompatible options":
 */
#ifdef ENABLE_VERBOSE
/** Descriptive text for the decode option */
#define DECODE_DESC      (tcpbridge_opt_strs+3597)
/** Upper-cased name for the decode option */
#define DECODE_NAME      (tcpbridge_opt_strs+3633)
/** Name string for the decode option */
#define DECODE_name      (tcpbridge_opt_strs+3640)
/** Other options that are required by the decode option */
static int const aDecodeMustList[] = {
    INDEX_OPT_VERBOSE, NO_EQUIVALENT };
/** Compiled in flag settings for the decode option */
#define DECODE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

#else   /* disable decode */
#define DECODE_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define aDecodeMustList   NULL
#define DECODE_NAME      NULL
#define DECODE_DESC      NULL
#define DECODE_name      NULL
#endif  /* ENABLE_VERBOSE */

/**
 *  version option description:
 */
/** Descriptive text for the version option */
#define VERSION_DESC      (tcpbridge_opt_strs+3647)
/** Upper-cased name for the version option */
#define VERSION_NAME      (tcpbridge_opt_strs+3673)
/** Name string for the version option */
#define VERSION_name      (tcpbridge_opt_strs+3681)
/** Compiled in flag settings for the version option */
#define VERSION_FLAGS     (OPTST_DISABLED)

/**
 *  less-help option description:
 */
/** Descriptive text for the less-help option */
#define LESS_HELP_DESC      (tcpbridge_opt_strs+3689)
/** Upper-cased name for the less-help option */
#define LESS_HELP_NAME      (tcpbridge_opt_strs+3729)
/** Name string for the less-help option */
#define LESS_HELP_name      (tcpbridge_opt_strs+3739)
/** Compiled in flag settings for the less-help option */
#define LESS_HELP_FLAGS     (OPTST_DISABLED | OPTST_IMM)

/*
 *  Help/More_Help option descriptions:
 */
#define HELP_DESC       (tcpbridge_opt_strs+3749)
#define HELP_name       (tcpbridge_opt_strs+3793)
#ifdef HAVE_WORKING_FORK
#define MORE_HELP_DESC  (tcpbridge_opt_strs+3798)
#define MORE_HELP_name  (tcpbridge_opt_strs+3843)
#define MORE_HELP_FLAGS (OPTST_IMM | OPTST_NO_INIT)
#else
#define MORE_HELP_DESC  HELP_DESC
#define MORE_HELP_name  HELP_name
#define MORE_HELP_FLAGS (OPTST_OMITTED | OPTST_NO_INIT)
#endif
#define SAVE_OPTS_DESC  (tcpbridge_opt_strs+3853)
#define SAVE_OPTS_name  (tcpbridge_opt_strs+3892)
#define LOAD_OPTS_DESC     (tcpbridge_opt_strs+3902)
#define LOAD_OPTS_NAME     (tcpbridge_opt_strs+3934)
#define NO_LOAD_OPTS_name  (tcpbridge_opt_strs+3944)
#define LOAD_OPTS_pfx      (tcpbridge_opt_strs+3957)
#define LOAD_OPTS_name     (NO_LOAD_OPTS_name + 3)
/**
 *  Declare option callback procedures
 */
#ifdef DEBUG
  static tOptProc doOptDbug;
#else /* not DEBUG */
# define doOptDbug NULL
#endif /* def/not DEBUG */
#ifdef ENABLE_PCAP_FINDALLDEVS
  static tOptProc doOptListnics;
#else /* not ENABLE_PCAP_FINDALLDEVS */
# define doOptListnics NULL
#endif /* def/not ENABLE_PCAP_FINDALLDEVS */
extern tOptProc
    optionBooleanVal,   optionNestedVal,    optionNumericVal,
    optionPagedUsage,   optionPrintVersion, optionResetOpt,
    optionStackArg,     optionTimeDate,     optionTimeVal,
    optionUnstackArg,   optionVendorOption;
static tOptProc
    doOptEnet_Mac_Seed_Keep_Bytes, doOptEnet_Vlan_Cfi,
    doOptEnet_Vlan_Pri,            doOptEnet_Vlan_Tag,
    doOptExclude,                  doOptFlowlabel,
    doOptFuzz_Factor,              doOptFuzz_Seed,
    doOptInclude,                  doOptLess_Help,
    doOptLimit,                    doOptMtu,
    doOptPid,                      doOptTclass,
    doOptTcp_Sequence,             doOptTos,
    doOptVersion,                  doUsageOpt;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 *  Define the tcpbridge Option Descriptions.
 * This is an array of OPTION_CT entries, one for each
 * option that the tcpbridge program responds to.
 */
static tOptDesc optDesc[OPTION_CT] = {
  {  /* entry idx, value */ 0, 0,
     /* equiv idx, value */ 0, 0,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 0, 0,
     /* opt state flags  */ TCPEDIT_FLAGS, 0,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ TCPEDIT_DESC, NULL, NULL,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 1, VALUE_OPT_PORTMAP,
     /* equiv idx, value */ 1, VALUE_OPT_PORTMAP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 9999, 0,
     /* opt state flags  */ PORTMAP_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --portmap */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionStackArg,
     /* desc, NAME, name */ PORTMAP_DESC, PORTMAP_NAME, PORTMAP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 2, VALUE_OPT_SEED,
     /* equiv idx, value */ 2, VALUE_OPT_SEED,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SEED_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --seed */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aSeedCantList,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ SEED_DESC, SEED_NAME, SEED_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 3, VALUE_OPT_PNAT,
     /* equiv idx, value */ 3, VALUE_OPT_PNAT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 2, 0,
     /* opt state flags  */ PNAT_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --pnat */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aPnatCantList,
     /* option proc      */ optionStackArg,
     /* desc, NAME, name */ PNAT_DESC, PNAT_NAME, PNAT_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 4, VALUE_OPT_SRCIPMAP,
     /* equiv idx, value */ 4, VALUE_OPT_SRCIPMAP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SRCIPMAP_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --srcipmap */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aSrcipmapCantList,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SRCIPMAP_DESC, SRCIPMAP_NAME, SRCIPMAP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 5, VALUE_OPT_DSTIPMAP,
     /* equiv idx, value */ 5, VALUE_OPT_DSTIPMAP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DSTIPMAP_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --dstipmap */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aDstipmapCantList,
     /* option proc      */ NULL,
     /* desc, NAME, name */ DSTIPMAP_DESC, DSTIPMAP_NAME, DSTIPMAP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 6, VALUE_OPT_ENDPOINTS,
     /* equiv idx, value */ 6, VALUE_OPT_ENDPOINTS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENDPOINTS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --endpoints */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aEndpointsMustList, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ENDPOINTS_DESC, ENDPOINTS_NAME, ENDPOINTS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 7, VALUE_OPT_TCP_SEQUENCE,
     /* equiv idx, value */ 7, VALUE_OPT_TCP_SEQUENCE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TCP_SEQUENCE_FLAGS, 0,
     /* last opt argumnt */ { TCP_SEQUENCE_DFT_ARG },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptTcp_Sequence,
     /* desc, NAME, name */ TCP_SEQUENCE_DESC, TCP_SEQUENCE_NAME, TCP_SEQUENCE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 8, VALUE_OPT_SKIPBROADCAST,
     /* equiv idx, value */ 8, VALUE_OPT_SKIPBROADCAST,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SKIPBROADCAST_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --skipbroadcast */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SKIPBROADCAST_DESC, SKIPBROADCAST_NAME, SKIPBROADCAST_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 9, VALUE_OPT_FIXCSUM,
     /* equiv idx, value */ 9, VALUE_OPT_FIXCSUM,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FIXCSUM_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --fixcsum */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ FIXCSUM_DESC, FIXCSUM_NAME, FIXCSUM_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 10, VALUE_OPT_MTU,
     /* equiv idx, value */ 10, VALUE_OPT_MTU,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ MTU_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --mtu */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptMtu,
     /* desc, NAME, name */ MTU_DESC, MTU_NAME, MTU_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 11, VALUE_OPT_MTU_TRUNC,
     /* equiv idx, value */ 11, VALUE_OPT_MTU_TRUNC,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ MTU_TRUNC_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --mtu-trunc */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ MTU_TRUNC_DESC, MTU_TRUNC_NAME, MTU_TRUNC_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 12, VALUE_OPT_EFCS,
     /* equiv idx, value */ 12, VALUE_OPT_EFCS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ EFCS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --efcs */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ EFCS_DESC, EFCS_NAME, EFCS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 13, VALUE_OPT_TTL,
     /* equiv idx, value */ 13, VALUE_OPT_TTL,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TTL_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --ttl */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ TTL_DESC, TTL_NAME, TTL_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 14, VALUE_OPT_TOS,
     /* equiv idx, value */ 14, VALUE_OPT_TOS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TOS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --tos */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptTos,
     /* desc, NAME, name */ TOS_DESC, TOS_NAME, TOS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 15, VALUE_OPT_TCLASS,
     /* equiv idx, value */ 15, VALUE_OPT_TCLASS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TCLASS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --tclass */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptTclass,
     /* desc, NAME, name */ TCLASS_DESC, TCLASS_NAME, TCLASS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 16, VALUE_OPT_FLOWLABEL,
     /* equiv idx, value */ 16, VALUE_OPT_FLOWLABEL,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FLOWLABEL_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --flowlabel */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptFlowlabel,
     /* desc, NAME, name */ FLOWLABEL_DESC, FLOWLABEL_NAME, FLOWLABEL_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 17, VALUE_OPT_FIXLEN,
     /* equiv idx, value */ 17, VALUE_OPT_FIXLEN,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FIXLEN_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --fixlen */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ FIXLEN_DESC, FIXLEN_NAME, FIXLEN_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 18, VALUE_OPT_FUZZ_SEED,
     /* equiv idx, value */ 18, VALUE_OPT_FUZZ_SEED,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FUZZ_SEED_FLAGS, 0,
     /* last opt argumnt */ { FUZZ_SEED_DFT_ARG },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptFuzz_Seed,
     /* desc, NAME, name */ FUZZ_SEED_DESC, FUZZ_SEED_NAME, FUZZ_SEED_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 19, VALUE_OPT_FUZZ_FACTOR,
     /* equiv idx, value */ 19, VALUE_OPT_FUZZ_FACTOR,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FUZZ_FACTOR_FLAGS, 0,
     /* last opt argumnt */ { FUZZ_FACTOR_DFT_ARG },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aFuzz_FactorMustList, NULL,
     /* option proc      */ doOptFuzz_Factor,
     /* desc, NAME, name */ FUZZ_FACTOR_DESC, FUZZ_FACTOR_NAME, FUZZ_FACTOR_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 20, VALUE_OPT_SKIPL2BROADCAST,
     /* equiv idx, value */ 20, VALUE_OPT_SKIPL2BROADCAST,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SKIPL2BROADCAST_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --skipl2broadcast */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SKIPL2BROADCAST_DESC, SKIPL2BROADCAST_NAME, SKIPL2BROADCAST_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 21, VALUE_OPT_DLT,
     /* equiv idx, value */ 21, VALUE_OPT_DLT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DLT_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --dlt */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ DLT_DESC, DLT_NAME, DLT_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 22, VALUE_OPT_ENET_DMAC,
     /* equiv idx, value */ 22, VALUE_OPT_ENET_DMAC,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_DMAC_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-dmac */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ENET_DMAC_DESC, ENET_DMAC_NAME, ENET_DMAC_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 23, VALUE_OPT_ENET_SMAC,
     /* equiv idx, value */ 23, VALUE_OPT_ENET_SMAC,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_SMAC_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-smac */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ENET_SMAC_DESC, ENET_SMAC_NAME, ENET_SMAC_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 24, VALUE_OPT_ENET_SUBSMAC,
     /* equiv idx, value */ 24, VALUE_OPT_ENET_SUBSMAC,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 9999, 0,
     /* opt state flags  */ ENET_SUBSMAC_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-subsmac */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionStackArg,
     /* desc, NAME, name */ ENET_SUBSMAC_DESC, ENET_SUBSMAC_NAME, ENET_SUBSMAC_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 25, VALUE_OPT_ENET_MAC_SEED,
     /* equiv idx, value */ 25, VALUE_OPT_ENET_MAC_SEED,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_MAC_SEED_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-mac-seed */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aEnet_Mac_SeedCantList,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ ENET_MAC_SEED_DESC, ENET_MAC_SEED_NAME, ENET_MAC_SEED_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 26, VALUE_OPT_ENET_MAC_SEED_KEEP_BYTES,
     /* equiv idx, value */ 26, VALUE_OPT_ENET_MAC_SEED_KEEP_BYTES,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_MAC_SEED_KEEP_BYTES_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-mac-seed-keep-bytes */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aEnet_Mac_Seed_Keep_BytesMustList, NULL,
     /* option proc      */ doOptEnet_Mac_Seed_Keep_Bytes,
     /* desc, NAME, name */ ENET_MAC_SEED_KEEP_BYTES_DESC, ENET_MAC_SEED_KEEP_BYTES_NAME, ENET_MAC_SEED_KEEP_BYTES_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 27, VALUE_OPT_ENET_VLAN,
     /* equiv idx, value */ 27, VALUE_OPT_ENET_VLAN,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_VLAN_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-vlan */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ENET_VLAN_DESC, ENET_VLAN_NAME, ENET_VLAN_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 28, VALUE_OPT_ENET_VLAN_TAG,
     /* equiv idx, value */ 28, VALUE_OPT_ENET_VLAN_TAG,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_VLAN_TAG_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-vlan-tag */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aEnet_Vlan_TagMustList, NULL,
     /* option proc      */ doOptEnet_Vlan_Tag,
     /* desc, NAME, name */ ENET_VLAN_TAG_DESC, ENET_VLAN_TAG_NAME, ENET_VLAN_TAG_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 29, VALUE_OPT_ENET_VLAN_CFI,
     /* equiv idx, value */ 29, VALUE_OPT_ENET_VLAN_CFI,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_VLAN_CFI_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-vlan-cfi */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aEnet_Vlan_CfiMustList, NULL,
     /* option proc      */ doOptEnet_Vlan_Cfi,
     /* desc, NAME, name */ ENET_VLAN_CFI_DESC, ENET_VLAN_CFI_NAME, ENET_VLAN_CFI_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 30, VALUE_OPT_ENET_VLAN_PRI,
     /* equiv idx, value */ 30, VALUE_OPT_ENET_VLAN_PRI,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_VLAN_PRI_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-vlan-pri */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aEnet_Vlan_PriMustList, NULL,
     /* option proc      */ doOptEnet_Vlan_Pri,
     /* desc, NAME, name */ ENET_VLAN_PRI_DESC, ENET_VLAN_PRI_NAME, ENET_VLAN_PRI_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 31, VALUE_OPT_ENET_VLAN_PROTO,
     /* equiv idx, value */ 31, VALUE_OPT_ENET_VLAN_PROTO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_VLAN_PROTO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-vlan-proto */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ENET_VLAN_PROTO_DESC, ENET_VLAN_PROTO_NAME, ENET_VLAN_PROTO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 32, VALUE_OPT_HDLC_CONTROL,
     /* equiv idx, value */ 32, VALUE_OPT_HDLC_CONTROL,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ HDLC_CONTROL_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --hdlc-control */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ HDLC_CONTROL_DESC, HDLC_CONTROL_NAME, HDLC_CONTROL_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 33, VALUE_OPT_HDLC_ADDRESS,
     /* equiv idx, value */ 33, VALUE_OPT_HDLC_ADDRESS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ HDLC_ADDRESS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --hdlc-address */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ HDLC_ADDRESS_DESC, HDLC_ADDRESS_NAME, HDLC_ADDRESS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 34, VALUE_OPT_USER_DLT,
     /* equiv idx, value */ 34, VALUE_OPT_USER_DLT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ USER_DLT_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --user-dlt */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ USER_DLT_DESC, USER_DLT_NAME, USER_DLT_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 35, VALUE_OPT_USER_DLINK,
     /* equiv idx, value */ 35, VALUE_OPT_USER_DLINK,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 2, 0,
     /* opt state flags  */ USER_DLINK_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --user-dlink */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionStackArg,
     /* desc, NAME, name */ USER_DLINK_DESC, USER_DLINK_NAME, USER_DLINK_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 36, VALUE_OPT_DBUG,
     /* equiv idx, value */ 36, VALUE_OPT_DBUG,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DBUG_FLAGS, 0,
     /* last opt argumnt */ { DBUG_DFT_ARG },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptDbug,
     /* desc, NAME, name */ DBUG_DESC, DBUG_NAME, DBUG_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 37, VALUE_OPT_INTF1,
     /* equiv idx, value */ 37, VALUE_OPT_INTF1,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 1, 1, 0,
     /* opt state flags  */ INTF1_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --intf1 */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ INTF1_DESC, INTF1_NAME, INTF1_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 38, VALUE_OPT_INTF2,
     /* equiv idx, value */ 38, VALUE_OPT_INTF2,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ INTF2_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --intf2 */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ INTF2_DESC, INTF2_NAME, INTF2_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 39, VALUE_OPT_UNIDIR,
     /* equiv idx, value */ 39, VALUE_OPT_UNIDIR,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ UNIDIR_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --unidir */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ UNIDIR_DESC, UNIDIR_NAME, UNIDIR_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 40, VALUE_OPT_LISTNICS,
     /* equiv idx, value */ 40, VALUE_OPT_LISTNICS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LISTNICS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --listnics */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptListnics,
     /* desc, NAME, name */ LISTNICS_DESC, LISTNICS_NAME, LISTNICS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 41, VALUE_OPT_LIMIT,
     /* equiv idx, value */ 41, VALUE_OPT_LIMIT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LIMIT_FLAGS, 0,
     /* last opt argumnt */ { LIMIT_DFT_ARG },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptLimit,
     /* desc, NAME, name */ LIMIT_DESC, LIMIT_NAME, LIMIT_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 42, VALUE_OPT_MAC,
     /* equiv idx, value */ 42, VALUE_OPT_MAC,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 2, 0,
     /* opt state flags  */ MAC_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --mac */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionStackArg,
     /* desc, NAME, name */ MAC_DESC, MAC_NAME, MAC_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 43, VALUE_OPT_INCLUDE,
     /* equiv idx, value */ 43, VALUE_OPT_INCLUDE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ INCLUDE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --include */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aIncludeCantList,
     /* option proc      */ doOptInclude,
     /* desc, NAME, name */ INCLUDE_DESC, INCLUDE_NAME, INCLUDE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 44, VALUE_OPT_EXCLUDE,
     /* equiv idx, value */ 44, VALUE_OPT_EXCLUDE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ EXCLUDE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --exclude */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aExcludeCantList,
     /* option proc      */ doOptExclude,
     /* desc, NAME, name */ EXCLUDE_DESC, EXCLUDE_NAME, EXCLUDE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 45, VALUE_OPT_PID,
     /* equiv idx, value */ 45, VALUE_OPT_PID,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ PID_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --pid */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptPid,
     /* desc, NAME, name */ PID_DESC, PID_NAME, PID_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 46, VALUE_OPT_VERBOSE,
     /* equiv idx, value */ 46, VALUE_OPT_VERBOSE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERBOSE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verbose */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERBOSE_DESC, VERBOSE_NAME, VERBOSE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 47, VALUE_OPT_DECODE,
     /* equiv idx, value */ 47, VALUE_OPT_DECODE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DECODE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --decode */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aDecodeMustList, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ DECODE_DESC, DECODE_NAME, DECODE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 48, VALUE_OPT_VERSION,
     /* equiv idx, value */ 48, VALUE_OPT_VERSION,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERSION_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --version */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptVersion,
     /* desc, NAME, name */ VERSION_DESC, VERSION_NAME, VERSION_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 49, VALUE_OPT_LESS_HELP,
     /* equiv idx, value */ 49, VALUE_OPT_LESS_HELP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LESS_HELP_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --less-help */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptLess_Help,
     /* desc, NAME, name */ LESS_HELP_DESC, LESS_HELP_NAME, LESS_HELP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_HELP, VALUE_OPT_HELP,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_HELP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OPTST_IMM | OPTST_NO_INIT, AOUSE_HELP,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doUsageOpt,
     /* desc, NAME, name */ HELP_DESC, NULL, HELP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_MORE_HELP, VALUE_OPT_MORE_HELP,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_MORE_HELP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ MORE_HELP_FLAGS, AOUSE_MORE_HELP,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL,  NULL,
     /* option proc      */ optionPagedUsage,
     /* desc, NAME, name */ MORE_HELP_DESC, NULL, MORE_HELP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_SAVE_OPTS, VALUE_OPT_SAVE_OPTS,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_SAVE_OPTS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OPTST_SET_ARGTYPE(OPARG_TYPE_STRING)
                       | OPTST_ARG_OPTIONAL | OPTST_NO_INIT, AOUSE_SAVE_OPTS,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL,  NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SAVE_OPTS_DESC, NULL, SAVE_OPTS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_LOAD_OPTS, VALUE_OPT_LOAD_OPTS,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_LOAD_OPTS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, NOLIMIT, 0,
     /* opt state flags  */ OPTST_SET_ARGTYPE(OPARG_TYPE_STRING)
			  | OPTST_DISABLE_IMM, AOUSE_LOAD_OPTS,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionLoadOpt,
     /* desc, NAME, name */ LOAD_OPTS_DESC, LOAD_OPTS_NAME, LOAD_OPTS_name,
     /* disablement strs */ NO_LOAD_OPTS_name, LOAD_OPTS_pfx }
};

tOptDesc * const tcpedit_tcpedit_optDesc_p = optDesc + 0;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/** Reference to the upper cased version of tcpbridge. */
#define zPROGNAME       (tcpbridge_opt_strs+3960)
/** Reference to the title line for tcpbridge usage. */
#define zUsageTitle     (tcpbridge_opt_strs+3970)
/** tcpbridge configuration file name. */
#define zRcName         (tcpbridge_opt_strs+4101)
/** Directories to search for tcpbridge config files. */
static char const * const apzHomeList[2] = {
    tcpbridge_opt_strs+4097,
    NULL };
/** The tcpbridge program bug email address. */
#define zBugsAddr       (tcpbridge_opt_strs+4114)
/** Clarification/explanation of what tcpbridge does. */
#define zExplain        (tcpbridge_opt_strs+4152)
/** Extra detail explaining what tcpbridge does. */
#define zDetail         (tcpbridge_opt_strs+4284)
/** The full version string for tcpbridge. */
#define zFullVersion    (NULL)
/* extracted from optcode.tlib near line 342 */

#if defined(ENABLE_NLS)
# define OPTPROC_BASE OPTPROC_TRANSLATE
  static tOptionXlateProc translate_option_strings;
#else
# define OPTPROC_BASE OPTPROC_NONE
# define translate_option_strings NULL
#endif /* ENABLE_NLS */

#define tcpbridge_full_usage (NULL)
#define tcpbridge_short_usage (NULL)

#endif /* not defined __doxygen__ */

/*
 *  Create the static procedure(s) declared above.
 */
/**
 * The callout function that invokes the optionUsage function.
 *
 * @param[in] opts the AutoOpts option description structure
 * @param[in] od   the descriptor for the "help" (usage) option.
 * @noreturn
 */
static void
doUsageOpt(tOptions * opts, tOptDesc * od)
{
    int ex_code;
    ex_code = TCPBRIDGE_EXIT_SUCCESS;
    optionUsage(&tcpbridgeOptions, ex_code);
    /* NOTREACHED */
    exit(TCPBRIDGE_EXIT_FAILURE);
    (void)opts;
    (void)od;
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the tcp-sequence option.
 * Change all TCP sequence numbers, and related sequence-acknowledgement numbers.
 * They will be shifted by a random amount based on the provided seed.
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptTcp_Sequence(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 1, LONG_MAX } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the mtu option.
 * Override the default 1500 byte MTU size for determining the maximum padding length
 * (--fixlen=pad) or when truncating (--mtu-trunc).
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptMtu(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 1, MAX_SNAPLEN } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the tos option.
 * Allows you to override the TOS (also known as DiffServ/ECN) value in IPv4.
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptTos(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 255 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the tclass option.
 * Allows you to override the IPv6 Traffic Class field.
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptTclass(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 255 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the flowlabel option.
 * Allows you to override the 20bit IPv6 Flow Label field.  Has no effect on IPv4
 * packets.
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptFlowlabel(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 1048575 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the fuzz-seed option.
 * This fuzzing was designed as to test layer 7 protocols such as voip protocols.
 * It modifies randomly 1 out of X packets (where X = @var{--fuzz-factor}) in order
 * for stateful protocols to cover more of their code.  The random fuzzing actions
 * focus on data start and end because it often is the part of the data application
 * protocols base their decisions on.
 *
 * Possible fuzzing actions list:
 *  * drop packet
 *  * reduce packet size
 *  * edit packet Bytes:
 *    * Not all Bytes have the same probability of appearance in real life.
 *      Replace with 0x00, 0xFF, or a random byte with equal likelihood.
 *    * Not all Bytes have the same significance in a packet.
 *      Replace the start, the end, or the middle of the packet with equal likelihood.
 *  * do nothing (7 out of 8 packets)
 *
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptFuzz_Seed(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, LONG_MAX } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the fuzz-factor option.
 * Sets the ratio of for @var{--fuzz-seed} option. By default this value is 8,
 * which means 1 in 8 packets are modified by fuzzing. Note that this ratio is
 * based on the random number generated by the supplied fuzz seed. Therefore by
 * default you cannot expect that exactly every eighth packet will be modified.
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptFuzz_Factor(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 1, LONG_MAX } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the enet-mac-seed-keep-bytes option.
 * Keep some bytes untouched when usinging @var{--enet-mac-seed} option.
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptEnet_Mac_Seed_Keep_Bytes(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 1, 6 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the enet-vlan-tag option.
 *
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptEnet_Vlan_Tag(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 4095 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the enet-vlan-cfi option.
 *
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptEnet_Vlan_Cfi(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 1 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the enet-vlan-pri option.
 *
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptEnet_Vlan_Pri(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 7 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the dbug option, when DEBUG is #define-d.
 * If configured with --enable-debug, then you can specify a verbosity
 * level for debugging output.  Higher numbers increase verbosity.
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
#ifdef DEBUG
static void
doOptDbug(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 5 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}
#endif /* defined DEBUG */

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the listnics option, when ENABLE_PCAP_FINDALLDEVS is #define-d.
 *
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
#ifdef ENABLE_PCAP_FINDALLDEVS
static void
doOptListnics(tOptions* pOptions, tOptDesc* pOptDesc)
{
    /*
     * Be sure the flag-code[0] handles special values for the options pointer
     * viz. (poptions <= OPTPROC_EMIT_LIMIT) *and also* the special flag bit
     * ((poptdesc->fOptState & OPTST_RESET) != 0) telling the option to
     * reset its state.
     */
    /* extracted from tcpbridge_opts.def, line 172 */

interface_list_t *list = get_interface_list();
list_interfaces(list);
free(list);
exit(0);

    (void)pOptDesc;
    (void)pOptions;
}
#endif /* defined ENABLE_PCAP_FINDALLDEVS */

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the limit option.
 * By default, tcpbridge will send packets forever or until Ctrl-C.  Alternatively,
 * you can specify a maximum number of packets to send.
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptLimit(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 1, LONG_MAX } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the include option.
 * Override default of sending all packets stored in the capture file and only
 * send packets which match the provided rule.  Rules can be one of:
 *
 * @table @bullet
 * @item S:<CIDR1>,...
 * - Source IP must match specified CIDR(s)
 * @item D:<CIDR1>,...
 * - Destination IP must match specified CIDR(s)
 * @item B:<CIDR1>,...
 * - Both source and destination IP must match specified CIDR(s)
 * @item E:<CIDR1>,...
 * - Either IP must match specified CIDR(s)
 * @item P:<LIST>
 * - Must be one of the listed packets where the list
 * corresponds to the packet number in the capture file.
 * @example
 * --include=P:1-5,9,15,72-
 * @end example
 * would send packets 1 through 5, the 9th and 15th packet, and packets 72 until the
 * end of the file
 * @item F:'<bpf>'
 * - BPF filter.  See the @file{tcpdump(8)} man page for syntax.
 * @end table
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptInclude(tOptions* pOptions, tOptDesc* pOptDesc)
{
    /*
     * Be sure the flag-code[0] handles special values for the options pointer
     * viz. (poptions <= OPTPROC_EMIT_LIMIT) *and also* the special flag bit
     * ((poptdesc->fOptState & OPTST_RESET) != 0) telling the option to
     * reset its state.
     */
    /* extracted from tcpbridge_opts.def, line 229 */

    char *include;

    include = safe_strdup(OPT_ARG(INCLUDE));
    options.xX.mode = xX_MODE_INCLUDE;

    if ((options.xX.mode = parse_xX_str(&options.xX, include, &options.bpf)) == xXError)
        errx(-1, "Unable to parse include/exclude rule: %s", OPT_ARG(INCLUDE));

    free(include);

    (void)pOptDesc;
    (void)pOptions;
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the exclude option.
 * Override default of sending all packets stored in the capture file and only
 * send packets which do not match the provided rule.  Rules can be one of:
 *
 * @table @bullet
 * @item S:<CIDR1>,...
 * - Source IP must not match specified CIDR(s)
 * @item D:<CIDR1>,...
 * - Destination IP must not match specified CIDR(s)
 * @item B:<CIDR1>,...
 * - Both source and destination IP must not match specified CIDR(s)
 * @item E:<CIDR1>,...
 * - Either IP must not match specified CIDR(s)
 * @item P:<LIST>
 * - Must not be one of the listed packets where the list
 * corresponds to the packet number in the capture file.
 * @example
 * --exclude=P:1-5,9,15,72-
 * @end example
 * would drop packets 1 through 5, the 9th and 15th packet, and packets 72 until the
 * end of the file
 * @end table
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptExclude(tOptions* pOptions, tOptDesc* pOptDesc)
{
    /*
     * Be sure the flag-code[0] handles special values for the options pointer
     * viz. (poptions <= OPTPROC_EMIT_LIMIT) *and also* the special flag bit
     * ((poptdesc->fOptState & OPTST_RESET) != 0) telling the option to
     * reset its state.
     */
    /* extracted from tcpbridge_opts.def, line 276 */

    char *exclude;

    exclude = safe_strdup(OPT_ARG(EXCLUDE));
    options.xX.mode = xX_MODE_EXCLUDE;

    if ((options.xX.mode = parse_xX_str(&options.xX, exclude, &options.bpf)) == xXError)
        errx(-1, "Unable to parse include/exclude rule: %s", OPT_ARG(EXCLUDE));

    free(exclude);

    (void)pOptDesc;
    (void)pOptions;
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the pid option.
 *
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptPid(tOptions* pOptions, tOptDesc* pOptDesc)
{
    /*
     * Be sure the flag-code[0] handles special values for the options pointer
     * viz. (poptions <= OPTPROC_EMIT_LIMIT) *and also* the special flag bit
     * ((poptdesc->fOptState & OPTST_RESET) != 0) telling the option to
     * reset its state.
     */
    /* extracted from tcpbridge_opts.def, line 318 */

    fprintf(stderr, "PID: %d\n", getpid());

    (void)pOptDesc;
    (void)pOptions;
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the version option.
 *
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptVersion(tOptions* pOptions, tOptDesc* pOptDesc)
{
    /*
     * Be sure the flag-code[0] handles special values for the options pointer
     * viz. (poptions <= OPTPROC_EMIT_LIMIT) *and also* the special flag bit
     * ((poptdesc->fOptState & OPTST_RESET) != 0) telling the option to
     * reset its state.
     */
    /* extracted from tcpbridge_opts.def, line 363 */

    fprintf(stderr, "tcpbridge version: %s (build %s)", VERSION, git_version());
#ifdef DEBUG
    fprintf(stderr, " (debug)");
#endif
    fprintf(stderr, "\n");
    fprintf(stderr, "Copyright 2013-2022 by Fred Klassen <tcpreplay at appneta dot com> - AppNeta\n");
    fprintf(stderr, "Copyright 2000-2012 by Aaron Turner <aturner at synfin dot net>\n");
    fprintf(stderr, "The entire Tcpreplay Suite is licensed under the GPLv3\n");
#ifdef HAVE_LIBDNET
    fprintf(stderr, "Compiled against libdnet: %s\n", LIBDNET_VERSION);
#else
    fprintf(stderr, "Not compiled with libdnet.\n");
#endif
#ifdef HAVE_WINPCAP
    fprintf(stderr, "Compiled against winpcap: %s\n", get_pcap_version());
#elif defined HAVE_PF_RING_PCAP
    fprintf(stderr, "Compiled against PF_RING libpcap: %s\n", get_pcap_version());
#else
    fprintf(stderr, "Compiled against libpcap: %s\n", get_pcap_version());
#endif
#ifdef ENABLE_64BITS
    fprintf(stderr, "64 bit packet counters: enabled\n");
#else
    fprintf(stderr, "64 bit packet counters: disabled\n");
#endif
#ifdef ENABLE_VERBOSE
    fprintf(stderr, "Verbose printing via tcpdump: enabled\n");
#else
    fprintf(stderr, "Verbose printing via tcpdump: disabled\n");
#endif
    fprintf(stderr, "Injection method: %s\n", sendpacket_get_method(NULL));

    exit(0);

    (void)pOptDesc;
    (void)pOptions;
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the less-help option.
 *
 * @param[in] pOptions the tcpbridge options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptLess_Help(tOptions* pOptions, tOptDesc* pOptDesc)
{
    /*
     * Be sure the flag-code[0] handles special values for the options pointer
     * viz. (poptions <= OPTPROC_EMIT_LIMIT) *and also* the special flag bit
     * ((poptdesc->fOptState & OPTST_RESET) != 0) telling the option to
     * reset its state.
     */
    /* extracted from tcpbridge_opts.def, line 408 */

    USAGE(EXIT_FAILURE);

    (void)pOptDesc;
    (void)pOptions;
}
/* extracted from optmain.tlib near line 1250 */

/**
 * The directory containing the data associated with tcpbridge.
 */
#ifndef  PKGDATADIR
# define PKGDATADIR ""
#endif

/**
 * Information about the person or institution that packaged tcpbridge
 * for the current distribution.
 */
#ifndef  WITH_PACKAGER
# define tcpbridge_packager_info NULL
#else
/** Packager information for tcpbridge. */
static char const tcpbridge_packager_info[] =
    "Packaged by " WITH_PACKAGER

# ifdef WITH_PACKAGER_VERSION
        " ("WITH_PACKAGER_VERSION")"
# endif

# ifdef WITH_PACKAGER_BUG_REPORTS
    "\nReport tcpbridge bugs to " WITH_PACKAGER_BUG_REPORTS
# endif
    "\n";
#endif
#ifndef __doxygen__

#endif /* __doxygen__ */
/**
 * The option definitions for tcpbridge.  The one structure that
 * binds them all.
 */
tOptions tcpbridgeOptions = {
    OPTIONS_STRUCT_VERSION,
    0, NULL,                    /* original argc + argv    */
    ( OPTPROC_BASE
    + OPTPROC_ERRSTOP
    + OPTPROC_SHORTOPT
    + OPTPROC_LONGOPT
    + OPTPROC_NO_REQ_OPT
    + OPTPROC_NO_ARGS
    + OPTPROC_GNUUSAGE ),
    0, NULL,                    /* current option index, current option */
    NULL,         NULL,         zPROGNAME,
    zRcName,      zCopyright,   zLicenseDescrip,
    zFullVersion, apzHomeList,  zUsageTitle,
    zExplain,     zDetail,      optDesc,
    zBugsAddr,                  /* address to send bugs to */
    NULL, NULL,                 /* extensions/saved state  */
    optionUsage, /* usage procedure */
    translate_option_strings,   /* translation procedure */
    /*
     *  Indexes to special options
     */
    { INDEX_OPT_MORE_HELP, /* more-help option index */
      INDEX_OPT_SAVE_OPTS, /* save option index */
      NO_EQUIVALENT, /* '-#' option index */
      10 /* index of default opt */
    },
    54 /* full option count */, 50 /* user option count */,
    tcpbridge_full_usage, tcpbridge_short_usage,
    NULL, NULL,
    PKGDATADIR, tcpbridge_packager_info
};

#if ENABLE_NLS
/**
 * This code is designed to translate translatable option text for the
 * tcpbridge program.  These translations happen upon entry
 * to optionProcess().
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#ifdef HAVE_DCGETTEXT
# include <gettext.h>
#endif
#include <autoopts/usage-txt.h>

static char * AO_gettext(char const * pz);
static void   coerce_it(void ** s);

/**
 * AutoGen specific wrapper function for gettext.  It relies on the macro _()
 * to convert from English to the target language, then strdup-duplicates the
 * result string.  It tries the "libopts" domain first, then whatever has been
 * set via the \a textdomain(3) call.
 *
 * @param[in] pz the input text used as a lookup key.
 * @returns the translated text (if there is one),
 *   or the original text (if not).
 */
static char *
AO_gettext(char const * pz)
{
    char * res;
    if (pz == NULL)
        return NULL;
#ifdef HAVE_DCGETTEXT
    /*
     * While processing the option_xlateable_txt data, try to use the
     * "libopts" domain.  Once we switch to the option descriptor data,
     * do *not* use that domain.
     */
    if (option_xlateable_txt.field_ct != 0) {
        res = dgettext("libopts", pz);
        if (res == pz)
            res = (char *)VOIDP(_(pz));
    } else
        res = (char *)VOIDP(_(pz));
#else
    res = (char *)VOIDP(_(pz));
#endif
    if (res == pz)
        return res;
    res = strdup(res);
    if (res == NULL) {
        fputs(_("No memory for duping translated strings\n"), stderr);
        exit(TCPBRIDGE_EXIT_FAILURE);
    }
    return res;
}

/**
 * All the pointers we use are marked "* const", but they are stored in
 * writable memory.  Coerce the mutability and set the pointer.
 */
static void coerce_it(void ** s) { *s = AO_gettext(*s);
}

/**
 * Translate all the translatable strings in the tcpbridgeOptions
 * structure defined above.  This is done only once.
 */
static void
translate_option_strings(void)
{
    tOptions * const opts = &tcpbridgeOptions;

    /*
     *  Guard against re-translation.  It won't work.  The strings will have
     *  been changed by the first pass through this code.  One shot only.
     */
    if (option_xlateable_txt.field_ct != 0) {
        /*
         *  Do the translations.  The first pointer follows the field count
         *  field.  The field count field is the size of a pointer.
         */
        char ** ppz = (char**)VOIDP(&(option_xlateable_txt));
        int     ix  = option_xlateable_txt.field_ct;

        do {
            ppz++; /* skip over field_ct */
            *ppz = AO_gettext(*ppz);
        } while (--ix > 0);
        /* prevent re-translation and disable "libopts" domain lookup */
        option_xlateable_txt.field_ct = 0;

        coerce_it(VOIDP(&(opts->pzCopyright)));
        coerce_it(VOIDP(&(opts->pzCopyNotice)));
        coerce_it(VOIDP(&(opts->pzFullVersion)));
        coerce_it(VOIDP(&(opts->pzUsageTitle)));
        coerce_it(VOIDP(&(opts->pzExplain)));
        coerce_it(VOIDP(&(opts->pzDetail)));
        {
            tOptDesc * od = opts->pOptDesc;
            for (ix = opts->optCt; ix > 0; ix--, od++)
                coerce_it(VOIDP(&(od->pzText)));
        }
    }
}
#endif /* ENABLE_NLS */

#ifdef DO_NOT_COMPILE_THIS_CODE_IT_IS_FOR_GETTEXT
/** I18N function strictly for xgettext.  Do not compile. */
static void bogus_function(void) {
  /* TRANSLATORS:

     The following dummy function was crated solely so that xgettext can
     extract the correct strings.  These strings are actually referenced
     by a field name in the tcpbridgeOptions structure noted in the
     comments below.  The literal text is defined in tcpbridge_opt_strs.

     NOTE: the strings below are segmented with respect to the source string
     tcpbridge_opt_strs.  The strings above are handed off for translation
     at run time a paragraph at a time.  Consequently, they are presented here
     for translation a paragraph at a time.

     ALSO: often the description for an option will reference another option
     by name.  These are set off with apostrophe quotes (I hope).  Do not
     translate option names.
   */
  /* referenced via tcpbridgeOptions.pzCopyright */
  puts(_("tcpbridge (tcpbridge)\n\
Copyright (C) 2000-2022 Aaron Turner and Fred Klassen, all rights reserved.\n\
This is free software. It is licensed for use, modification and\n\
redistribution under the terms of the GNU General Public License,\n\
version 3 or later <http://gnu.org/licenses/gpl.html>\n"));

  /* referenced via tcpbridgeOptions.pzCopyNotice */
  puts(_("tcpbridge is free software: you can redistribute it and/or modify it under\n\
the terms of the GNU General Public License as published by the Free\n\
Software Foundation, either version 3 of the License, or (at your option)\n\
any later version.\n\n"));
  puts(_("tcpbridge is distributed in the hope that it will be useful, but WITHOUT\n\
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or\n\
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for\n\
more details.\n\n"));
  puts(_("You should have received a copy of the GNU General Public License along\n\
with this program.  If not, see <http://www.gnu.org/licenses/>.\n"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_(":"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Rewrite TCP/UDP ports"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Randomize src/dst IPv4/v6 addresses w/ given seed"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Rewrite IPv4/v6 addresses using pseudo-NAT"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Rewrite source IPv4/v6 addresses using pseudo-NAT"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Rewrite destination IPv4/v6 addresses using pseudo-NAT"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Rewrite IP addresses to be between two endpoints"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Change TCP Sequence (and ACK) numbers /w given seed"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Skip rewriting broadcast/multicast IPv4/v6 addresses"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Force recalculation of IPv4/TCP/UDP header checksums"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Override default MTU length (1500 bytes)"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Truncate packets larger then specified MTU"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Remove Ethernet checksums (FCS) from end of frames"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Modify the IPv4/v6 TTL/Hop Limit"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Set the IPv4 TOS/DiffServ/ECN byte"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Set the IPv6 Traffic Class byte"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Set the IPv6 Flow Label"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Pad or truncate packet data to match header length"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Fuzz 1 in X packets.  Edit bytes, length, or emulate packet drop"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Set the Fuzz 1 in X packet ratio (default 1 in 8 packets)"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Skip rewriting broadcast/multicast Layer 2 addresses"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Override output DLT encapsulation"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Override destination ethernet MAC addresses"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Override source ethernet MAC addresses"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Substitute MAC addresses"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Randomize MAC addresses"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Randomize MAC addresses"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Specify ethernet 802.1q VLAN tag mode"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Specify the new ethernet 802.1q VLAN tag value"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Specify the ethernet 802.1q VLAN CFI value"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Specify the ethernet 802.1q VLAN priority"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Specify VLAN tag protocol 802.1q or 802.1ad"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Specify HDLC control value"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Specify HDLC address"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Set output file DLT type"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Rewrite Data-Link layer with user specified data"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Enable debugging output"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Primary interface (listen in uni-directional mode)"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Secondary interface (send in uni-directional mode)"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Send and receive in only one direction"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("List available network interfaces and exit"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Limit the number of packets to send"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("MAC addresses of local NIC's"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Include only packets matching rule"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Exclude any packet matching this rule"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Print the PID of tcpbridge at startup"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Print decoded packets via tcpdump to STDOUT"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Arguments passed to tcpdump decoder"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Print version information"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("Display less usage information and exit"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("display extended usage information and exit"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("extended usage information passed thru pager"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("save the option state to a config file"));

  /* referenced via tcpbridgeOptions.pOptDesc->pzText */
  puts(_("load options from a config file"));

  /* referenced via tcpbridgeOptions.pzUsageTitle */
  puts(_("tcpbridge (tcpbridge) - Bridge network traffic across two interfaces\n\
Usage:  %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]...\n"));

  /* referenced via tcpbridgeOptions.pzExplain */
  puts(_("tcpbridge is a tool for selectively bridging network traffic across two\n\
interfaces and optionally modifying the packets in between\n"));

  /* referenced via tcpbridgeOptions.pzDetail */
  puts(_("The basic operation of tcpbridge is to be a network bridge between two\n\
subnets.  All packets received on one interface are sent via the other.\n\n"));
  puts(_("Optionally, packets can be edited in a variety of ways according to your\n\
needs.\n\n\
For more details, please see the Tcpreplay Manual at:\n\
http://tcpreplay.appneta.com\n"));

  /* referenced via tcpbridgeOptions.pzFullUsage */
  puts(_("<<<NOT-FOUND>>>"));

  /* referenced via tcpbridgeOptions.pzShortUsage */
  puts(_("<<<NOT-FOUND>>>"));
  /* LIBOPTS-MESSAGES: */
#line 67 "../autoopts.c"
  puts(_("allocation of %d bytes failed\n"));
#line 89 "../autoopts.c"
  puts(_("allocation of %d bytes failed\n"));
#line 48 "../init.c"
  puts(_("AutoOpts function called without option descriptor\n"));
#line 81 "../init.c"
  puts(_("\tThis exceeds the compiled library version:  "));
#line 79 "../init.c"
  puts(_("Automated Options Processing Error!\n"
       "\t%s called AutoOpts function with structure version %d:%d:%d.\n"));
#line 78 "../autoopts.c"
  puts(_("realloc of %d bytes at 0x%p failed\n"));
#line 83 "../init.c"
  puts(_("\tThis is less than the minimum library version:  "));
#line 121 "../version.c"
  puts(_("Automated Options version %s\n"
       "\tCopyright (C) 1999-2017 by Bruce Korb - all rights reserved\n"));
#line 49 "../makeshell.c"
  puts(_("(AutoOpts bug):  %s.\n"));
#line 90 "../reset.c"
  puts(_("optionResetOpt() called, but reset-option not configured"));
#line 241 "../usage.c"
  puts(_("could not locate the 'help' option"));
#line 330 "../autoopts.c"
  puts(_("optionProcess() was called with invalid data"));
#line 697 "../usage.c"
  puts(_("invalid argument type specified"));
#line 568 "../find.c"
  puts(_("defaulted to option with optional arg"));
#line 76 "../alias.c"
  puts(_("aliasing option is out of range."));
#line 210 "../enum.c"
  puts(_("%s error:  the keyword '%s' is ambiguous for %s\n"));
#line 78 "../find.c"
  puts(_("  The following options match:\n"));
#line 263 "../find.c"
  puts(_("%s: ambiguous option name: %s (matches %d options)\n"));
#line 161 "../check.c"
  puts(_("%s: Command line arguments required\n"));
#line 43 "../alias.c"
  puts(_("%d %s%s options allowed\n"));
#line 56 "../makeshell.c"
  puts(_("%s error %d (%s) calling %s for '%s'\n"));
#line 268 "../makeshell.c"
  puts(_("interprocess pipe"));
#line 171 "../version.c"
  puts(_("error: version option argument '%c' invalid.  Use:\n"
       "\t'v' - version only\n"
       "\t'c' - version and copyright\n"
       "\t'n' - version and full copyright notice\n"));
#line 58 "../check.c"
  puts(_("%s error:  the '%s' and '%s' options conflict\n"));
#line 187 "../find.c"
  puts(_("%s: The '%s' option has been disabled."));
#line 400 "../find.c"
  puts(_("%s: The '%s' option has been disabled."));
#line 38 "../alias.c"
  puts(_("-equivalence"));
#line 439 "../find.c"
  puts(_("%s: illegal option -- %c\n"));
#line 110 "../reset.c"
  puts(_("%s: illegal option -- %c\n"));
#line 241 "../find.c"
  puts(_("%s: illegal option -- %s\n"));
#line 740 "../find.c"
  puts(_("%s: illegal option -- %s\n"));
#line 118 "../reset.c"
  puts(_("%s: illegal option -- %s\n"));
#line 305 "../find.c"
  puts(_("%s: unknown vendor extension option -- %s\n"));
#line 135 "../enum.c"
  puts(_("  or an integer from %d through %d\n"));
#line 145 "../enum.c"
  puts(_("  or an integer from %d through %d\n"));
#line 696 "../usage.c"
  puts(_("%s error:  invalid option descriptor for %s\n"));
#line 1030 "../usage.c"
  puts(_("%s error:  invalid option descriptor for %s\n"));
#line 355 "../find.c"
  puts(_("%s: invalid option name: %s\n"));
#line 497 "../find.c"
  puts(_("%s: The '%s' option requires an argument.\n"));
#line 150 "../autoopts.c"
  puts(_("(AutoOpts bug):  Equivalenced option '%s' was equivalenced to both\n"
       "\t'%s' and '%s'."));
#line 94 "../check.c"
  puts(_("%s error:  The %s option is required\n"));
#line 602 "../find.c"
  puts(_("%s: The '%s' option cannot have an argument.\n"));
#line 151 "../check.c"
  puts(_("%s: Command line arguments are not allowed.\n"));
#line 568 "../save.c"
  puts(_("error %d (%s) creating %s\n"));
#line 210 "../enum.c"
  puts(_("%s error:  '%s' does not match any %s keywords.\n"));
#line 93 "../reset.c"
  puts(_("%s error: The '%s' option requires an argument.\n"));
#line 122 "../save.c"
  puts(_("error %d (%s) stat-ing %s\n"));
#line 175 "../save.c"
  puts(_("error %d (%s) stat-ing %s\n"));
#line 143 "../restore.c"
  puts(_("%s error: no saved option state\n"));
#line 225 "../autoopts.c"
  puts(_("'%s' is not a command line option.\n"));
#line 113 "../time.c"
  puts(_("%s error:  '%s' is not a recognizable date/time.\n"));
#line 50 "../time.c"
  puts(_("%s error:  '%s' is not a recognizable time duration.\n"));
#line 92 "../check.c"
  puts(_("%s error:  The %s option must appear %d times.\n"));
#line 165 "../numeric.c"
  puts(_("%s error:  '%s' is not a recognizable number.\n"));
#line 176 "../enum.c"
  puts(_("%s error:  %s exceeds %s keyword count\n"));
#line 279 "../usage.c"
  puts(_("Try '%s %s' for more information.\n"));
#line 45 "../alias.c"
  puts(_("one %s%s option allowed\n"));
#line 170 "../makeshell.c"
  puts(_("standard output"));
#line 905 "../makeshell.c"
  puts(_("standard output"));
#line 223 "../usage.c"
  puts(_("standard output"));
#line 364 "../usage.c"
  puts(_("standard output"));
#line 574 "../usage.c"
  puts(_("standard output"));
#line 178 "../version.c"
  puts(_("standard output"));
#line 223 "../usage.c"
  puts(_("standard error"));
#line 364 "../usage.c"
  puts(_("standard error"));
#line 574 "../usage.c"
  puts(_("standard error"));
#line 178 "../version.c"
  puts(_("standard error"));
#line 170 "../makeshell.c"
  puts(_("write"));
#line 905 "../makeshell.c"
  puts(_("write"));
#line 222 "../usage.c"
  puts(_("write"));
#line 363 "../usage.c"
  puts(_("write"));
#line 573 "../usage.c"
  puts(_("write"));
#line 177 "../version.c"
  puts(_("write"));
#line 60 "../numeric.c"
  puts(_("%s error:  %s option value %ld is out of range.\n"));
#line 44 "../check.c"
  puts(_("%s error:  %s option requires the %s option\n"));
#line 121 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 174 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 193 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 567 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
  /* END-LIBOPTS-MESSAGES */

  /* USAGE-TEXT: */
#line 822 "../usage.c"
  puts(_("\t\t\t\t- an alternate for '%s'\n"));
#line 1097 "../usage.c"
  puts(_("Version, usage and configuration options:"));
#line 873 "../usage.c"
  puts(_("\t\t\t\t- default option for unnamed options\n"));
#line 786 "../usage.c"
  puts(_("\t\t\t\t- disabled as '--%s'\n"));
#line 1066 "../usage.c"
  puts(_(" --- %-14s %s\n"));
#line 1064 "../usage.c"
  puts(_("This option has been disabled"));
#line 813 "../usage.c"
  puts(_("\t\t\t\t- enabled by default\n"));
#line 40 "../alias.c"
  puts(_("%s error:  only "));
#line 1143 "../usage.c"
  puts(_(" - examining environment variables named %s_*\n"));
#line 168 "../file.c"
  puts(_("\t\t\t\t- file must not pre-exist\n"));
#line 172 "../file.c"
  puts(_("\t\t\t\t- file must pre-exist\n"));
#line 329 "../usage.c"
  puts(_("Options are specified by doubled hyphens and their name or by a single\n"
       "hyphen and the flag character.\n"));
#line 882 "../makeshell.c"
  puts(_("\n"
       "= = = = = = = =\n\n"
       "This incarnation of genshell will produce\n"
       "a shell script to parse the options for %s:\n\n"));
#line 142 "../enum.c"
  puts(_("  or an integer mask with any of the lower %d bits set\n"));
#line 846 "../usage.c"
  puts(_("\t\t\t\t- is a set membership option\n"));
#line 867 "../usage.c"
  puts(_("\t\t\t\t- must appear between %d and %d times\n"));
#line 331 "../usage.c"
  puts(_("Options are specified by single or double hyphens and their name.\n"));
#line 853 "../usage.c"
  puts(_("\t\t\t\t- may appear multiple times\n"));
#line 840 "../usage.c"
  puts(_("\t\t\t\t- may not be preset\n"));
#line 1258 "../usage.c"
  puts(_("   Arg Option-Name    Description\n"));
#line 1194 "../usage.c"
  puts(_("  Flg Arg Option-Name    Description\n"));
#line 1252 "../usage.c"
  puts(_("  Flg Arg Option-Name    Description\n"));
#line 1253 "../usage.c"
  puts(_(" %3s %s"));
#line 1259 "../usage.c"
  puts(_(" %3s %s"));
#line 336 "../usage.c"
  puts(_("The '-#<number>' option may omit the hash char\n"));
#line 332 "../usage.c"
  puts(_("All arguments are named options.\n"));
#line 920 "../usage.c"
  puts(_(" - reading file %s"));
#line 358 "../usage.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 100 "../version.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 129 "../version.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 852 "../usage.c"
  puts(_("\t\t\t\t- may NOT appear - preset only\n"));
#line 893 "../usage.c"
  puts(_("\n"
       "The following option preset mechanisms are supported:\n"));
#line 1141 "../usage.c"
  puts(_("\n"
       "The following option preset mechanisms are supported:\n"));
#line 631 "../usage.c"
  puts(_("prohibits these options:\n"));
#line 626 "../usage.c"
  puts(_("prohibits the option '%s'\n"));
#line 81 "../numeric.c"
  puts(_("%s%ld to %ld"));
#line 79 "../numeric.c"
  puts(_("%sgreater than or equal to %ld"));
#line 75 "../numeric.c"
  puts(_("%s%ld exactly"));
#line 68 "../numeric.c"
  puts(_("%sit must lie in one of the ranges:\n"));
#line 68 "../numeric.c"
  puts(_("%sit must be in the range:\n"));
#line 88 "../numeric.c"
  puts(_(", or\n"));
#line 66 "../numeric.c"
  puts(_("%sis scalable with a suffix: k/K/m/M/g/G/t/T\n"));
#line 77 "../numeric.c"
  puts(_("%sless than or equal to %ld"));
#line 339 "../usage.c"
  puts(_("Operands and options may be intermixed.  They will be reordered.\n"));
#line 601 "../usage.c"
  puts(_("requires the option '%s'\n"));
#line 604 "../usage.c"
  puts(_("requires these options:\n"));
#line 1270 "../usage.c"
  puts(_("   Arg Option-Name   Req?  Description\n"));
#line 1264 "../usage.c"
  puts(_("  Flg Arg Option-Name   Req?  Description\n"));
#line 143 "../enum.c"
  puts(_("or you may use a numeric representation.  Preceding these with a '!'\n"
       "will clear the bits, specifying 'none' will clear all bits, and 'all'\n"
       "will set them all.  Multiple entries may be passed as an option\n"
       "argument list.\n"));
#line 859 "../usage.c"
  puts(_("\t\t\t\t- may appear up to %d times\n"));
#line 52 "../enum.c"
  puts(_("The valid \"%s\" option keywords are:\n"));
#line 1101 "../usage.c"
  puts(_("The next option supports vendor supported extra options:"));
#line 722 "../usage.c"
  puts(_("These additional options are:"));
  /* END-USAGE-TEXT */
}
#endif /* uncompilable code */
#ifdef  __cplusplus
}
#endif
/* tcpbridge_opts.c ends here */
